==> haskell-cborg-json-0.2.6.0-93.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-ENQDar75uITKXaSEp5mQRn
key:                  cborg-json-0.2.6.0-ENQDar75uITKXaSEp5mQRn
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  3bff253500f10bc8db408a82748353b0
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-ENQDar75uITKXaSEp5mQRn
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-pretty-0.8.10-CQgtmRgYKKmDAUdx88Og8E base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    cborg-0.2.10.0-68PDphg2ld87Sae9qXuISV
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cborg-json-0.2.6.0-94-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-L1X0hTIyMOa762Vhahk8aA
key:                  cborg-json-0.2.6.0-L1X0hTIyMOa762Vhahk8aA
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  d4b298e7edd381967245bc22971d86f4
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-L1X0hTIyMOa762Vhahk8aA
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    cborg-0.2.10.0-wdOqHOFjOn2vW0hKimWjL
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
